@@ -70,19 +70,10 @@ class ConstructedMolecule(Molecule):
 
         """
 
-        construction_result = topology_graph.construct()
-        super().__init__(
-            atoms=construction_result.get_atoms(),
-            bonds=construction_result.get_bonds(),
-            position_matrix=construction_result.get_position_matrix(),
+        self._init_from_construction_result(
+            obj=self,
+            construction_result=topology_graph.construct(),
         )
-        self._atom_infos = construction_result.get_atom_infos()
-        self._bond_infos = construction_result.get_bond_infos()
-        self._num_building_blocks = {
-            building_block:
-                topology_graph.get_num_building_block(building_block)
-            for building_block in topology_graph.get_building_blocks()
-        }
 
     @classmethod
     def init(
@@ -132,6 +123,74 @@ class ConstructedMolecule(Molecule):
         molecule._num_building_blocks = dict(num_building_blocks)
         return molecule
 
+    @classmethod
+    def init_from_construction_result(
+        cls,
+        construction_result,
+    ):
+        """
+        Initialize a :class:`.ConstructedMolecule`.
+
+        Parameters
+        ----------
+        construction_result : :class:`.ConstructionResult`
+            The result of a construction, from which the
+            :class:`.ConstructedMolecule` should be initialized.
+
+        Returns
+        -------
+        :class:`.ConstructedMolecule`
+            The constructed molecule.
+
+        """
+
+        return cls._init_from_construction_result(
+            obj=cls.__new__(cls),
+            construction_result=construction_result,
+        )
+
+    @staticmethod
+    def _init_from_construction_result(
+        obj,
+        construction_result,
+    ):
+        """
+        Initialize a :class:`.ConstructedMolecule`.
+
+        This modifies `obj`.
+
+        Parameters
+        ----------
+        obj : :class:`.ConstructedMolecule`
+            The constructed molecule to initialize.
+
+        construction_result : :class:`.ConstructionResult`
+            The result of a construction, from which the
+            :class:`.ConstructedMolecule` should be initialized.
+
+        Returns
+        -------
+        :class:`.ConstructedMolecule`
+            The `obj` instance.
+
+        """
+
+        super(ConstructedMolecule, obj).__init__(
+            atoms=construction_result.get_atoms(),
+            bonds=construction_result.get_bonds(),
+            position_matrix=construction_result.get_position_matrix(),
+        )
+        obj._atom_infos = construction_result.get_atom_infos()
+        obj._bond_infos = construction_result.get_bond_infos()
+        obj._num_building_blocks = {
+            building_block: construction_result.get_num_building_block(
+                building_block=building_block,
+            )
+            for building_block
+            in construction_result.get_building_blocks()
+        }
+        return obj
+
     def clone(self):
         clone = super().clone()
         clone._atom_infos = self._atom_infos
