@@ -693,7 +693,7 @@ class Molecule:
         Parameters
         ----------
         position_matrix : :class:`numpy.ndarray`
-            A position matrix of the clone. The shape of the matrix
+            The position matrix of the clone. The shape of the matrix
             is ``(n, 3)``.
 
         Returns
@@ -749,6 +749,7 @@ class Molecule:
         #. ``.xyz`` - XYZ files
         #. ``.mae`` - Schrodinger Maestro files
         #. ``.coord`` - Turbomole files
+        #. ``.pdb`` - PDB files
 
         Parameters
         ----------
@@ -777,6 +778,7 @@ class Molecule:
             '.mae': updaters._with_structure_from_mae,
             '.xyz': updaters._with_structure_from_xyz,
             '.coord': updaters._with_structure_from_turbomole,
+            '.pdb': updaters._with_structure_from_pdb,
         }[extension](self.clone(), path)
 
     def with_canonical_atom_ordering(self):
@@ -825,6 +827,25 @@ class Molecule:
         ]).T)
         return self
 
+    def get_canonical_atom_ids(self):
+        """
+        Map the id of each atom to its id under canonical ordering.
+
+        Returns
+        -------
+        :class:`dict`
+            Maps the id of each atom in the molecule to the id it would
+            have under canonical ordering.
+
+        """
+
+        return {
+            old_id: new_id
+            for old_id, new_id in enumerate(
+                rdkit.CanonicalRankAtoms(self.to_rdkit_mol()),
+            )
+        }
+
     def write(self, path, atom_ids=None):
         """
         Write the structure to a file.
@@ -868,7 +889,4 @@ class Molecule:
         return repr(self)
 
     def __repr__(self):
-        return (
-            f'{self.__class__.__name__}({self._atoms!r}, '
-            f'{self._bonds!r}, {self._position_matrix!r})'
-        )
+        return f'<{self.__class__.__name__} at {id(self)}>'
