@@ -1,3 +1,9 @@
+"""
+Cage Vertices
+=============
+
+"""
+
 import numpy as np
 from scipy.spatial.distance import euclidean
 
