@@ -1,3 +1,9 @@
+"""
+Graph State
+===========
+
+"""
+
 import numpy as np
 from collections import defaultdict
 
