@@ -1,4 +1,8 @@
 """
+Utilities
+=========
+
+
 This module defines general-purpose objects, functions and classes.
 
 Functions, classes, etc. defined here should not depend on any other
